menu
flutter_timezone package
documentation
flutter_timezone_web.dart
flutter_timezone_web.dart
dark_mode
light_mode
flutter_timezone_web
library
Classes
FlutterTimezonePlugin
The plugin class for the web, acts as the plugin inside bits and connects to the js world.
Functions
supportedValuesOf
(
JSString
value
)
→
JSArray
<
JSString
>
?
flutter_timezone package
documentation
flutter_timezone_web.dart
flutter_timezone
package
Libraries
flutter_timezone
flutter_timezone_web
timezone_info
flutter_timezone_web library