flutter_timezone_web library
Classes
- FlutterTimezonePlugin
- The plugin class for the web, acts as the plugin inside bits and connects to the js world.
Functions
-
jsDateTimeFormat(
) → _JSDateTimeFormat -
supportedValuesOf(
JSString value) → JSArray< JSString> ?